/* diodemail - send-only smtp server
 * Copyright (c) 2024 Gnarwhal
 *
 * This file is part of SSHare.
 *
 * SSHare is free software: you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation,
 * either version 3 of the License, or (at your option) any later version.
 *
 * SSHare is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * SSHare. If not, see <https://www.gnu.org/licenses/>.
 */

package smtp

import (
	"net"

	"github.com/rs/zerolog/log"
)

type Connection struct {
	connection net.Conn
}

func (self Connection) Read() (string, error) {
	buffer := [64]byte{}
	read, err := self.connection.Read(buffer[:])
	if err != nil {
		return "", err
	}

	message := string(buffer[:read - 2])

	log.Trace().Msgf("%v  -> %v", self.RemoteAddr(), message)

	return message, nil
}

func (self Connection) Write(message string) error {
	log.Trace().Msgf("%v <-  %v", self.RemoteAddr(), message[:len(message) - 1])
	_, err := self.connection.Write([]byte(message))
	return err
}

func (self Connection) Close() {
	self.connection.Close()
}

func (self Connection) RemoteAddr() net.Addr {
	return self.connection.RemoteAddr()
}
